from loguru import logger
from trello import Card
from trello import List as TrelloList

from ai_trello_extract.dataclasses.categorized_list import CategorizedLists
from ai_trello_extract.dataclasses.trello_card import TrelloCard


def extract_card_info(trello_list: TrelloList, card: Card) -> TrelloCard:
    logger.debug(f"Extracting Trello Card information for card: {card.name}")
    return TrelloCard(
        list_name=trello_list.name,
        title=card.name,
        description=card.description,
        labels=[label.name for label in card.labels],
        comments=[comment["data"]["text"] for comment in card.comments],
        done_date=card.due_date,
    )


def trello_list_reducer(accumulator: CategorizedLists, trello_list: TrelloList) -> CategorizedLists:
    if trello_list.name in ["Icebox", "Epics"]:
        accumulator.planning.append(trello_list)
    elif trello_list.name in ["Backlog"]:
        accumulator.todo.append(trello_list)
    elif trello_list.name in ["Doing"]:
        accumulator.doing.append(trello_list)
    elif trello_list.name in ["Target User Personas"]:
        accumulator.users.append(trello_list)
    elif trello_list.name in ["Virtual Team"]:
        accumulator.team.append(trello_list)
    else:
        accumulator.done.append(trello_list)
    return accumulator
